@@ -26,6 +26,63 @@
 
 
 
+template <class T> 
+void calc_metric(int O, int D, const std::vector<T> &TABLE, const T *in, float *metric, trellis_metric_type_t type)
+{
+  float minm = FLT_MAX;
+  int minmi = 0;
+
+  switch (type){
+  case TRELLIS_EUCLIDEAN:
+    for(int o=0;o<O;o++) {
+      metric[o]=0.0;
+      for (int m=0;m<D;m++) {
+        T s=in[m]-TABLE[o*D+m];
+        //gr_complex sc(1.0*s,0);
+        //metric[o]+=(sc*conj(sc)).real();
+        metric[o]+= s * s;
+      }
+    }
+    break;
+  case TRELLIS_HARD_SYMBOL:
+    for(int o=0;o<O;o++) {
+      metric[o]=0.0;
+      for (int m=0;m<D;m++) {
+        T s=in[m]-TABLE[o*D+m];
+        //gr_complex sc(1.0*s,0);
+        //metric[o]+=(sc*conj(sc)).real();
+        metric[o]+= s * s;
+      }
+      if(metric[o]<minm) {
+        minm=metric[o];
+        minmi=o;
+      }
+    }
+    for(int o=0;o<O;o++) {
+      metric[o] = (o==minmi?0.0:1.0);
+    }
+    break;
+  case TRELLIS_HARD_BIT:
+    throw std::runtime_error ("Invalid metric type (not yet implemented).");
+    break;
+  default:
+    throw std::runtime_error ("Invalid metric type.");
+  }
+}
+
+
+
+template
+void calc_metric<short>(int O, int D, const std::vector<short> &TABLE, const short *in, float *metric, trellis_metric_type_t type);
+
+template
+void calc_metric<int>(int O, int D, const std::vector<int> &TABLE, const int *in, float *metric, trellis_metric_type_t type);
+
+template
+void calc_metric<float>(int O, int D, const std::vector<float> &TABLE, const float *in, float *metric, trellis_metric_type_t type);
+
+
+/*
 void calc_metric(int O, int D, const std::vector<short> &TABLE, const short *in, float *metric, trellis_metric_type_t type)
 {
   float minm = FLT_MAX;
@@ -145,6 +202,10 @@ void calc_metric(int O, int D, const std::vector<float> &TABLE, const float *in,
     throw std::runtime_error ("Invalid metric type.");
   }
 }
+*/
+
+
+
 
 
 void calc_metric(int O, int D, const std::vector<gr_complex> &TABLE, const gr_complex *in, float *metric, trellis_metric_type_t type)
@@ -184,47 +245,3 @@ void calc_metric(int O, int D, const std::vector<gr_complex> &TABLE, const gr_co
     throw std::runtime_error ("Invalid metric type.");
   }
 }
-
-
-/*
-template <class T> void calc_metric(int O, int D, const std::vector<T> &TABLE, const T *in, float *metric, trellis_metric_type_t type)
-{
-  float minm = FLT_MAX;
-  int minmi = 0;
-
-  switch (type){
-  case TRELLIS_EUCLIDEAN:
-    for(int o=0;o<O;o++) {
-      metric[o]=0.0;
-      for (int m=0;m<D;m++) {
-        T s=in[m]-TABLE[o*D+m];
-        gr_complex sc(1.0*s,0);
-        metric[o]+=(s*conj(s)).real();
-      }
-    }
-    break;
-  case TRELLIS_HARD_SYMBOL:
-    for(int o=0;o<O;o++) {
-      metric[o]=0.0;
-      for (int m=0;m<D;m++) {
-        T s=in[m]-TABLE[o*D+m];
-        gr_complex sc(1.0*s,0);
-        metric[o]+=(s*conj(s)).real();
-      }
-      if(metric[o]<minm) {
-        minm=metric[o];
-        minmi=o;
-      }
-    }
-    for(int o=0;o<O;o++) {
-      metric[o] = (o==minmi?0.0:1.0);
-    }
-    break;
-  case TRELLIS_HARD_BIT:
-    throw std::runtime_error ("Invalid metric type (not yet implemented).");
-    break;
-  default:
-    throw std::runtime_error ("Invalid metric type.");
-  }
-}
-*/
