@@ -1,5 +1,5 @@
 #
-# Copyright 2005 Free Software Foundation, Inc.
+# Copyright 2005,2007 Free Software Foundation, Inc.
 # 
 # This file is part of GNU Radio
 # 
@@ -22,10 +22,10 @@
 from gnuradio import usrp1
 import time,math
 
-import usrp_dbid
+from usrpm import usrp_dbid
 import db_base
 import db_instantiator
-from usrp_fpga_regs import *
+from usrpm.usrp_fpga_regs import *
 
 #debug_using_gui = True                  # Must be set to True or False
 debug_using_gui = False                  # Must be set to True or False
@@ -98,7 +98,7 @@ class flexrf_base(db_base.db_base):
         Adds 10ms delay between writing control and N if this is first call.
         This is the required power-up sequence.
         
-        @param $: 24-bit R counter latch
+        @param R: 24-bit R counter latch
         @type R: int
         @param control: 24-bit control latch
         @type control: int
@@ -169,7 +169,7 @@ class flexrf_base(db_base.db_base):
         # FPGA's DC removal loop's time constant.  We were seeing a
         # problem when running with discontinuous transmission.
         # Offsetting the LO made the problem go away.
-        freq += self.lo_offset
+        freq += self._lo_offset
         
         R, control, N, actual_freq = self._compute_regs(freq)
         if R==0:
@@ -211,6 +211,22 @@ class flexrf_base(db_base.db_base):
         """
         return True
 
+    def set_lo_offset(self, offset):
+	"""
+	Set amount by which LO is offset from requested tuning frequency.
+	
+	@param offset: offset in Hz
+	"""
+	self._lo_offset = offset
+
+    def lo_offset(self):
+	"""
+	Get amount by which LO is offset from requested tuning frequency.
+	
+	@returns Offset in Hz
+	"""
+	return self._lo_offset
+	
 # ----------------------------------------------------------------
 
 class flexrf_base_tx(flexrf_base):
@@ -225,7 +241,7 @@ class flexrf_base_tx(flexrf_base):
         # power up the transmit side, but don't enable the mixer
         self._u._write_oe(self._which,(POWER_UP|RX_TXN|ENABLE), 0xffff)
         self._u.write_io(self._which, (self.power_on|RX_TXN), (POWER_UP|RX_TXN|ENABLE))
-        self.lo_offset = 4e6             # FIXME may want to be a function of d'board
+        self.set_lo_offset(4e6)
 
     def __del__(self):
         #print "flexrf_base_tx.__del__"
@@ -275,7 +291,6 @@ class flexrf_base_tx(flexrf_base):
         """
         return self._set_pga(self._u.pga_max())
 
-
 class flexrf_base_rx(flexrf_base):
     def __init__(self, usrp, which):
         """
@@ -292,8 +307,7 @@ class flexrf_base_rx(flexrf_base):
         self.select_rx_antenna('TX/RX')
 
         self.bypass_adc_buffers(True)
-
-        self.lo_offset = -4e6             # FIXME may want to be a function of d'board
+        self.set_lo_offset(-4e6)
 
     def __del__(self):
         # print "flexrf_base_rx.__del__"
@@ -331,6 +345,7 @@ class flexrf_base_rx(flexrf_base):
         @returns True/False
         """
         maxgain = self.gain_range()[1] - self._u.pga_max()
+        mingain = self.gain_range()[0]
         if gain > maxgain:
             pga_gain = gain-maxgain
             assert pga_gain <= self._u.pga_max()
@@ -341,12 +356,11 @@ class flexrf_base_rx(flexrf_base):
         V_maxgain = .2
         V_mingain = 1.2
         V_fullscale = 3.3
-        dac_value = (agc_gain*(V_maxgain-V_mingain)/maxgain + V_mingain)*4096/V_fullscale
+        dac_value = (agc_gain*(V_maxgain-V_mingain)/(maxgain-mingain) + V_mingain)*4096/V_fullscale
         assert dac_value>=0 and dac_value<4096
         return self._u.write_aux_dac(self._which, 0, int(dac_value)) and \
                self._set_pga(int(pga_gain))
 
-
 # ----------------------------------------------------------------
 
 class _AD4360_common(object):
